==> nextcloud-24.0.8.tgz: nextcloud/apps/dashboard/l10n/uk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Майстерня",
    "Dashboard app" : "Застосунок з панеллю віджетів ",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Почніть свій день інформовано \nІнформаційна панель Nextcloud — це ваша початкова точка дня, яка дає вам змогу огляд ваших майбутніх зустрічей, термінових електронних листів, повідомлень чату, вхідні квитки, останні твіти та багато іншого! Користувачі можуть додавати віджети вони люблять і змінюють фон на свій смак.",
    "Customize" : "Редагувати",
    "Edit widgets" : "Редагувати віджети",
    "Get more widgets from the App Store" : "Більше віджетів у каталозі застосунків",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Для забезпечення вашої конфіденційності дані про погоду запитуються вашим сервером Nextcloud від вашого імені, тому служба погоди не отримує особисту інформацію.",
    "Weather data from Met.no" : "Дані про погоду з Met.no",
    "geocoding with Nominatim" : "геокодування за допомогою Nominatim",
    "elevation data from OpenTopoData" : "дані про висоту з OpenTopoData",
    "Weather" : "Погода",
    "Status" : "Статус",
    "Good morning" : "Доброго ранку",
    "Good morning, {name}" : "Доброго ранку, {name}",
    "Good afternoon" : "Добрий день",
    "Good afternoon, {name}" : "Добрий день, {name}",
    "Good evening" : "Добрий вечір",
    "Good evening, {name}" : "Добрий вечір, {name}",
    "Hello" : "Привіт",
    "Hello, {name}" : "Привіт, {name}",
    "Show something" : "Показати щось",
    "Change background image" : "Змінити фонову світлину",
    "Pick from Files" : "Виберіть із файлів",
    "Default images" : "Типові зображення",
    "Plain background" : "Рівний фон",
    "Insert from {productName}" : "Вставка з {productName}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.11.tgz: nextcloud/apps/dashboard/l10n/uk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Майстерня",
    "Dashboard app" : "Застосунок з панеллю віджетів ",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Почніть свій день інформовано \nІнформаційна панель Nextcloud — це ваша початкова точка дня, яка дає вам змогу огляд ваших майбутніх зустрічей, термінових електронних листів, повідомлень чату, вхідні квитки, останні твіти та багато іншого! Користувачі можуть додавати віджети вони люблять і змінюють фон на свій смак.",
    "Customize" : "Редагувати",
    "Edit widgets" : "Редагувати віджети",
    "Get more widgets from the App Store" : "Більше віджетів у каталозі застосунків",
    "Weather service" : "Погода",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Для забезпечення вашої конфіденційності дані про погоду запитуються вашим сервером Nextcloud від вашого імені, тому служба погоди не отримує особисту інформацію.",
    "Weather data from Met.no" : "Дані про погоду з Met.no",
    "geocoding with Nominatim" : "геокодування за допомогою Nominatim",
    "elevation data from OpenTopoData" : "дані про висоту з OpenTopoData",
    "Weather" : "Погода",
    "Status" : "Статус",
    "Good morning" : "Доброго ранку",
    "Good morning, {name}" : "Доброго ранку, {name}",
    "Good afternoon" : "Добрий день",
    "Good afternoon, {name}" : "Добрий день, {name}",
    "Good evening" : "Добрий вечір",
    "Good evening, {name}" : "Добрий вечір, {name}",
    "Hello" : "Привіт",
    "Hello, {name}" : "Привіт, {name}",
    "Change background image" : "Змінити зображення тла",
    "Pick from Files" : "Виберіть із файлів",
    "Default images" : "Типові зображення",
    "Plain background" : "Однокольорове тло",
    "Insert from {productName}" : "Вставка з {productName}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
